TableResponse class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

TableResponse({String? singleRecordName, String? pluralRecordName, String? name, String? description, String? id, String? updated, String? created, String? alias, int? defaultSortFieldId, SortOrder? defaultSortOrder, int? keyFieldId, int? nextFieldId, int? nextRecordId, String? sizeLimit, String? spaceRemaining, String? spaceUsed})
TableResponse.fromJson(Map<String, dynamic> json)
factory

Properties

alias → String?
final
created → String?
final
defaultSortFieldId → int?
final
defaultSortOrder → SortOrder?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
keyFieldId → int?
final
name → String?
final
nextFieldId → int?
final
nextRecordId → int?
final
pluralRecordName → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleRecordName → String?
final
sizeLimit → String?
final
spaceRemaining → String?
final
spaceUsed → String?
final
updated → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited