UserTokenResponse class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

UserTokenResponse({String? name, String? description, int? id, String? token, bool? active, List<QuickbaseApp>? apps, String? lastUsed})
UserTokenResponse.fromJson(Map<String, dynamic> json)
factory

Properties

active → bool?
final
apps → List<QuickbaseApp>?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int?
final
lastUsed → String?
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited